@@ -24,6 +24,7 @@ import getpass
 import six
 from six.moves.urllib import parse
 from . import exit_codes, progress, utils, exceptions, pkg_info
+from .exceptions import InvalidFileError
 
 try:
     from concurrent.futures import ThreadPoolExecutor, Future
@@ -726,10 +727,9 @@ class Client(object):
 
         stat_result = os.stat(local_source_file)
         if stat_result.st_size > 30*1024*1024*1024:
-            print("Error: Uploading files larger than 30G is not allowed.")
-            return
+            raise InvalidFileError("Directly uploading files larger than 30G is not allowed. Please do chunked upload on this file instead.")
         if stat_result.st_size > 20*1024*1024*1024:
-            print("Warn: Uploading files larger than 20G is not guaranteed to be stable. Please split it into a number of smaller files.")
+            print("Warn: Directly uploading files larger than 20G is not guaranteed to be stable. Please do chunked upload on this file instead.")
         headers = {}
         mime_type = magic.from_file(local_source_file, mime=True)
         headers['Content-Type'] = mime_type
