@@ -998,7 +998,10 @@ def main():
         sys.exit(EX_USAGE)
 
     except HTTPResponseError as e:
-        error(u"Owncloud response error: %s" % e)
+        if e.status_code == 401:
+            error(u"Owncloud response error: %s, Username and password do not match, or your password has been expired." % e)
+        else:
+            error(u"Owncloud response error: %s" % e)
         sys.exit(e.get_error_code())
 
     except SystemExit as e:
